<template>
  <div class="card">
    <div class="card-body">
      <h4
        class="card-title"
        :class="$i18n.locale == 'ar' ? 'font-size-15' : ''"
      >
        {{ $t("app.set_scheduling") }}
      </h4>
      <div class="form-group">
        <el-select
          v-model="expire_date_label"
          class="form-select-solid col-12"
          :placeholder="row.expire_date_label"
        >
          <el-option
            :label="$t('app.one_time_invoice')"
            value="ONE_TIME_INVOICE"
          >
            <a class="dropdown-item" @click="onChange('ONE_TIME_INVOICE')">
              {{ $t("app.one_time_invoice") }}
            </a>
          </el-option>
          <el-option :label="$t('app.daily')" value="DAILY">
            <a class="dropdown-item" @click="onChange('DAILY')">
              {{ $t("app.daily") }}
            </a>
          </el-option>
          <el-option :label="$t('app.weekly')" value="WEEKLY">
            <a class="dropdown-item" @click="onChange('WEEKLY')">
              {{ $t("app.weekly") }}
            </a>
          </el-option>
          <el-option :label="$t('app.monthly')" value="MONTHLY">
            <a class="dropdown-item" @click="onChange('MONTHLY')">
              {{ $t("app.monthly") }}
            </a>
          </el-option>
          <el-option :label="$t('app.yearly')" value="YEARLY">
            <a class="dropdown-item" @click="onChange('YEARLY')">
              {{ $t("app.yearly") }}
            </a>
          </el-option>
        </el-select>
      </div>
    </div>
  </div>
</template>

<script>
export default {
  name: "CardScheduleType",
  props: ["scheduling_type"],
  data() {
    return {
      dataLoading: false,
      auth: {
        id_token: "",
      },
      expire_date_label: "",
      row: {
        scheduling_type: this.$props.scheduling_type,
      },
    };
  },
  created() {
    if (localStorage.getItem("id_token")) {
      this.auth.id_token = localStorage.getItem("id_token");
    }
    this.checkLabel();
  },
  methods: {
    checkLabel() {
      if (
        this.$props.scheduling_type == "ONE_TIME_INVOICE" ||
        this.$props.scheduling_type == undefined
      )
        this.expire_date_label = this.$t("app.one_time_invoice");
      else if (this.$props.scheduling_type == "DAILY")
        this.expire_date_label = this.$t("app.daily");
      else if (this.$props.scheduling_type == "WEEKLY")
        this.expire_date_label = this.$t("app.weekly");
      else if (this.$props.scheduling_type == "MONTHLY")
        this.expire_date_label = this.$t("app.monthly");
      else if (this.$props.scheduling_type == "YEARLY")
        this.expire_date_label = this.$t("app.yearly");
    },
    onChange(value) {
      this.row.scheduling_type = value;
      this.checkLabel();
      const data = {
        scheduling_type: this.row.scheduling_type,
      };
      this.$emit("schedulingTypeChange", data);
    },
    dateChange(event) {
      console.log(event);
    },
  },
};
</script>

<style scoped>
.scrollable-menu {
  height: auto;
  max-height: 18rem;
  overflow-x: hidden;
}

.input-group .input-group-btn .btn-secondary {
  color: #464a4c;
  background-color: #eceeef;
}

.input-group-addon {
  padding: 0.5rem 0.75rem;
  margin-bottom: 0;
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.25;
  color: #464a4c;
  text-align: center;
  background-color: #eceeef;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.input-group-btn {
  position: relative;
  font-size: 0;
  white-space: nowrap;
  vertical-align: middle;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  flex-direction: column;
  -webkit-box-pack: center;
  justify-content: center;
}

.input-group .input-group-btn .btn-secondary {
  color: #464a4c !important;
  background-color: #eceeef;
  margin-right: -1px;
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
  border: 1px solid #ced4da;
  border-left: none;
  position: relative;
  -webkit-box-flex: 1;
  flex: 1 1 0%;
}
</style>
